@@ -2,7 +2,7 @@
 /**
  * Object Cache API
  *
- * @link http://codex.wordpress.org/Function_Reference/WP_Cache
+ * @link https://codex.wordpress.org/Class_Reference/WP_Object_Cache
  *
  * @package WordPress
  * @subpackage Cache
@@ -12,14 +12,17 @@
  * Adds data to the cache, if the cache key doesn't already exist.
  *
  * @since 2.0.0
- * @uses $wp_object_cache Object Cache Class
- * @see WP_Object_Cache::add()
  *
- * @param int|string $key The cache key to use for retrieval later
- * @param mixed $data The data to add to the cache store
- * @param string $group The group to add the cache to
- * @param int $expire When the cache data should be expired
- * @return bool False if cache key and group already exist, true on success
+ * @see WP_Object_Cache::add()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int|string $key    The cache key to use for retrieval later.
+ * @param mixed      $data   The data to add to the cache.
+ * @param string     $group  Optional. The group to add the cache to. Enables the same key
+ *                           to be used across groups. Default empty.
+ * @param int        $expire Optional. When the cache data should expire, in seconds.
+ *                           Default 0 (no expiration).
+ * @return bool False if cache key and group already exist, true on success.
  */
 function wp_cache_add( $key, $data, $group = '', $expire = 0 ) {
 	global $wp_object_cache;
@@ -31,28 +34,30 @@ function wp_cache_add( $key, $data, $group = '', $expire = 0 ) {
  * Closes the cache.
  *
  * This function has ceased to do anything since WordPress 2.5. The
- * functionality was removed along with the rest of the persistent cache. This
- * does not mean that plugins can't implement this function when they need to
- * make sure that the cache is cleaned up after WordPress no longer needs it.
+ * functionality was removed along with the rest of the persistent cache.
+ *
+ * This does not mean that plugins can't implement this function when they need
+ * to make sure that the cache is cleaned up after WordPress no longer needs it.
  *
  * @since 2.0.0
  *
- * @return bool Always returns True
+ * @return true Always returns true.
  */
 function wp_cache_close() {
 	return true;
 }
 
 /**
- * Decrement numeric cache item's value
+ * Decrements numeric cache item's value.
  *
  * @since 3.3.0
- * @uses $wp_object_cache Object Cache Class
- * @see WP_Object_Cache::decr()
  *
- * @param int|string $key The cache key to increment
- * @param int $offset The amount by which to decrement the item's value. Default is 1.
- * @param string $group The group the key is in.
+ * @see WP_Object_Cache::decr()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int|string $key    The cache key to decrement.
+ * @param int        $offset Optional. The amount by which to decrement the item's value. Default 1.
+ * @param string     $group  Optional. The group the key is in. Default empty.
  * @return false|int False on failure, the item's new value on success.
  */
 function wp_cache_decr( $key, $offset = 1, $group = '' ) {
@@ -65,14 +70,15 @@ function wp_cache_decr( $key, $offset = 1, $group = '' ) {
  * Removes the cache contents matching key and group.
  *
  * @since 2.0.0
- * @uses $wp_object_cache Object Cache Class
- * @see WP_Object_Cache::delete()
  *
- * @param int|string $key What the contents in the cache are called
- * @param string $group Where the cache contents are grouped
- * @return bool True on successful removal, false on failure
+ * @see WP_Object_Cache::delete()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int|string $key   What the contents in the cache are called.
+ * @param string     $group Optional. Where the cache contents are grouped. Default empty.
+ * @return bool True on successful removal, false on failure.
  */
-function wp_cache_delete($key, $group = '') {
+function wp_cache_delete( $key, $group = '' ) {
 	global $wp_object_cache;
 
 	return $wp_object_cache->delete($key, $group);
@@ -82,8 +88,9 @@ function wp_cache_delete($key, $group = '') {
  * Removes all cache items.
  *
  * @since 2.0.0
- * @uses $wp_object_cache Object Cache Class
+ *
  * @see WP_Object_Cache::flush()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
  *
  * @return bool False on failure, true on success
  */
@@ -97,15 +104,18 @@ function wp_cache_flush() {
  * Retrieves the cache contents from the cache by key and group.
  *
  * @since 2.0.0
- * @uses $wp_object_cache Object Cache Class
- * @see WP_Object_Cache::get()
  *
- * @param int|string $key What the contents in the cache are called
- * @param string $group Where the cache contents are grouped
- * @param bool $force Whether to force an update of the local cache from the persistent cache (default is false)
- * @param &bool $found Whether key was found in the cache. Disambiguates a return of false, a storable value.
+ * @see WP_Object_Cache::get()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int|string  $key    The key under which the cache contents are stored.
+ * @param string      $group  Optional. Where the cache contents are grouped. Default empty.
+ * @param bool        $force  Optional. Whether to force an update of the local cache from the persistent
+ *                            cache. Default false.
+ * @param bool        $found  Optional. Whether the key was found in the cache. Disambiguates a return of false,
+ *                            a storable value. Passed by reference. Default null.
  * @return bool|mixed False on failure to retrieve contents or the cache
- *		contents on success
+ *		              contents on success
  */
 function wp_cache_get( $key, $group = '', $force = false, &$found = null ) {
 	global $wp_object_cache;
@@ -117,12 +127,13 @@ function wp_cache_get( $key, $group = '', $force = false, &$found = null ) {
  * Increment numeric cache item's value
  *
  * @since 3.3.0
- * @uses $wp_object_cache Object Cache Class
- * @see WP_Object_Cache::incr()
  *
- * @param int|string $key The cache key to increment
- * @param int $offset The amount by which to increment the item's value. Default is 1.
- * @param string $group The group the key is in.
+ * @see WP_Object_Cache::incr()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int|string $key    The key for the cache contents that should be incremented.
+ * @param int        $offset Optional. The amount by which to increment the item's value. Default 1.
+ * @param string     $group  Optional. The group the key is in. Default empty.
  * @return false|int False on failure, the item's new value on success.
  */
 function wp_cache_incr( $key, $offset = 1, $group = '' ) {
@@ -135,7 +146,8 @@ function wp_cache_incr( $key, $offset = 1, $group = '' ) {
  * Sets up Object Cache Global and assigns it.
  *
  * @since 2.0.0
- * @global WP_Object_Cache $wp_object_cache WordPress Object Cache
+ *
+ * @global WP_Object_Cache $wp_object_cache
  */
 function wp_cache_init() {
 	$GLOBALS['wp_object_cache'] = new WP_Object_Cache();
@@ -145,14 +157,17 @@ function wp_cache_init() {
  * Replaces the contents of the cache with new data.
  *
  * @since 2.0.0
- * @uses $wp_object_cache Object Cache Class
- * @see WP_Object_Cache::replace()
  *
- * @param int|string $key What to call the contents in the cache
- * @param mixed $data The contents to store in the cache
- * @param string $group Where to group the cache contents
- * @param int $expire When to expire the cache contents
- * @return bool False if not exists, true if contents were replaced
+ * @see WP_Object_Cache::replace()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int|string $key    The key for the cache data that should be replaced.
+ * @param mixed      $data   The new data to store in the cache.
+ * @param string     $group  Optional. The group for the cache data that should be replaced.
+ *                           Default empty.
+ * @param int        $expire Optional. When to expire the cache contents, in seconds.
+ *                           Default 0 (no expiration).
+ * @return bool False if original value does not exist, true if contents were replaced
  */
 function wp_cache_replace( $key, $data, $group = '', $expire = 0 ) {
 	global $wp_object_cache;
@@ -163,15 +178,19 @@ function wp_cache_replace( $key, $data, $group = '', $expire = 0 ) {
 /**
  * Saves the data to the cache.
  *
+ * Differs from wp_cache_add() and wp_cache_replace() in that it will always write data.
+ *
  * @since 2.0.0
  *
- * @uses $wp_object_cache Object Cache Class
  * @see WP_Object_Cache::set()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
  *
- * @param int|string $key What to call the contents in the cache
- * @param mixed $data The contents to store in the cache
- * @param string $group Where to group the cache contents
- * @param int $expire When to expire the cache contents
+ * @param int|string $key    The cache key to use for retrieval later.
+ * @param mixed      $data   The contents to store in the cache.
+ * @param string     $group  Optional. Where to group the cache contents. Enables the same key
+ *                           to be used across groups. Default empty.
+ * @param int        $expire Optional. When to expire the cache contents, in seconds.
+ *                           Default 0 (no expiration).
  * @return bool False on failure, true on success
  */
 function wp_cache_set( $key, $data, $group = '', $expire = 0 ) {
@@ -181,18 +200,21 @@ function wp_cache_set( $key, $data, $group = '', $expire = 0 ) {
 }
 
 /**
- * Switch the interal blog id.
+ * Switches the internal blog ID.
  *
  * This changes the blog id used to create keys in blog specific groups.
  *
  * @since 3.5.0
  *
- * @param int $blog_id Blog ID
+ * @see WP_Object_Cache::switch_to_blog()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param int $blog_id Site ID.
  */
 function wp_cache_switch_to_blog( $blog_id ) {
 	global $wp_object_cache;
 
-	return $wp_object_cache->switch_to_blog( $blog_id );
+	$wp_object_cache->switch_to_blog( $blog_id );
 }
 
 /**
@@ -200,12 +222,15 @@ function wp_cache_switch_to_blog( $blog_id ) {
  *
  * @since 2.6.0
  *
- * @param string|array $groups A group or an array of groups to add
+ * @see WP_Object_Cache::add_global_groups()
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
+ *
+ * @param string|array $groups A group or an array of groups to add.
  */
 function wp_cache_add_global_groups( $groups ) {
 	global $wp_object_cache;
 
-	return $wp_object_cache->add_global_groups( $groups );
+	$wp_object_cache->add_global_groups( $groups );
 }
 
 /**
@@ -213,38 +238,41 @@ function wp_cache_add_global_groups( $groups ) {
  *
  * @since 2.6.0
  *
- * @param string|array $groups A group or an array of groups to add
+ * @param string|array $groups A group or an array of groups to add.
  */
 function wp_cache_add_non_persistent_groups( $groups ) {
 	// Default cache doesn't persist so nothing to do here.
-	return;
 }
 
 /**
- * Reset internal cache keys and structures. If the cache backend uses global
- * blog or site IDs as part of its cache keys, this function instructs the
- * backend to reset those keys and perform any cleanup since blog or site IDs
- * have changed since cache init.
+ * Reset internal cache keys and structures.
+ *
+ * If the cache back end uses global blog or site IDs as part of its cache keys,
+ * this function instructs the back end to reset those keys and perform any cleanup
+ * since blog or site IDs have changed since cache init.
  *
  * This function is deprecated. Use wp_cache_switch_to_blog() instead of this
  * function when preparing the cache for a blog switch. For clearing the cache
  * during unit tests, consider using wp_cache_init(). wp_cache_init() is not
- * recommended outside of unit tests as the performance penality for using it is
+ * recommended outside of unit tests as the performance penalty for using it is
  * high.
  *
  * @since 2.6.0
- * @deprecated 3.5.0
+ * @deprecated 3.5.0 WP_Object_Cache::reset()
+ * @see WP_Object_Cache::reset()
+ *
+ * @global WP_Object_Cache $wp_object_cache Object cache global instance.
  */
 function wp_cache_reset() {
-	_deprecated_function( __FUNCTION__, '3.5' );
+	_deprecated_function( __FUNCTION__, '3.5.0' );
 
 	global $wp_object_cache;
 
-	return $wp_object_cache->reset();
+	$wp_object_cache->reset();
 }
 
 /**
- * WordPress Object Cache
+ * Core class that implements an object cache.
  *
  * The WordPress Object Cache is used to save on trips to the database. The
  * Object Cache stores all of the cache data to memory and makes the cache
@@ -262,11 +290,11 @@ function wp_cache_reset() {
 class WP_Object_Cache {
 
 	/**
-	 * Holds the cached objects
+	 * Holds the cached objects.
 	 *
-	 * @var array
-	 * @access private
 	 * @since 2.0.0
+	 * @access private
+	 * @var array
 	 */
 	private $cache = array();
 
@@ -274,40 +302,49 @@ class WP_Object_Cache {
 	 * The amount of times the cache data was already stored in the cache.
 	 *
 	 * @since 2.5.0
-	 * @access private
+	 * @access public
 	 * @var int
 	 */
-	private $cache_hits = 0;
+	public $cache_hits = 0;
 
 	/**
-	 * Amount of times the cache did not have the request in cache
+	 * Amount of times the cache did not have the request in cache.
 	 *
-	 * @var int
-	 * @access public
 	 * @since 2.0.0
+	 * @access public
+	 * @var int
 	 */
 	public $cache_misses = 0;
 
 	/**
-	 * List of global groups
+	 * List of global cache groups.
 	 *
-	 * @var array
-	 * @access protected
 	 * @since 3.0.0
+	 * @access protected
+	 * @var array
 	 */
 	protected $global_groups = array();
 
 	/**
 	 * The blog prefix to prepend to keys in non-global groups.
 	 *
-	 * @var int
-	 * @access private
 	 * @since 3.5.0
+	 * @access private
+	 * @var int
 	 */
 	private $blog_prefix;
 
 	/**
-	 * Make private properties readable for backwards compatibility.
+	 * Holds the value of is_multisite().
+	 *
+	 * @since 3.5.0
+	 * @access private
+	 * @var bool
+	 */
+	private $multisite;
+
+	/**
+	 * Makes private properties readable for backward compatibility.
 	 *
 	 * @since 4.0.0
 	 * @access public
@@ -320,7 +357,7 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Make private properties settable for backwards compatibility.
+	 * Makes private properties settable for backward compatibility.
 	 *
 	 * @since 4.0.0
 	 * @access public
@@ -334,7 +371,7 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Make private properties checkable for backwards compatibility.
+	 * Makes private properties checkable for backward compatibility.
 	 *
 	 * @since 4.0.0
 	 * @access public
@@ -347,7 +384,7 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Make private properties un-settable for backwards compatibility.
+	 * Makes private properties un-settable for backward compatibility.
 	 *
 	 * @since 4.0.0
 	 * @access public
@@ -361,16 +398,17 @@ class WP_Object_Cache {
 	/**
 	 * Adds data to the cache if it doesn't already exist.
 	 *
-	 * @uses WP_Object_Cache::_exists Checks to see if the cache already has data.
-	 * @uses WP_Object_Cache::set Sets the data after the checking the cache
-	 *		contents existence.
-	 *
 	 * @since 2.0.0
+	 * @access public
 	 *
-	 * @param int|string $key What to call the contents in the cache
-	 * @param mixed $data The contents to store in the cache
-	 * @param string $group Where to group the cache contents
-	 * @param int $expire When to expire the cache contents
+	 * @uses WP_Object_Cache::_exists() Checks to see if the cache already has data.
+	 * @uses WP_Object_Cache::set()     Sets the data after the checking the cache
+	 *		                            contents existence.
+	 *
+	 * @param int|string $key    What to call the contents in the cache.
+	 * @param mixed      $data   The contents to store in the cache.
+	 * @param string     $group  Optional. Where to group the cache contents. Default 'default'.
+	 * @param int        $expire Optional. When to expire the cache contents. Default 0 (no expiration).
 	 * @return bool False if cache key and group already exist, true on success
 	 */
 	public function add( $key, $data, $group = 'default', $expire = 0 ) {
@@ -391,9 +429,10 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Sets the list of global groups.
+	 * Sets the list of global cache groups.
 	 *
 	 * @since 3.0.0
+	 * @access public
 	 *
 	 * @param array $groups List of groups that are global.
 	 */
@@ -405,13 +444,14 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Decrement numeric cache item's value
+	 * Decrements numeric cache item's value.
 	 *
 	 * @since 3.3.0
+	 * @access public
 	 *
-	 * @param int|string $key The cache key to increment
-	 * @param int $offset The amount by which to decrement the item's value. Default is 1.
-	 * @param string $group The group the key is in.
+	 * @param int|string $key    The cache key to decrement.
+	 * @param int        $offset Optional. The amount by which to decrement the item's value. Default 1.
+	 * @param string     $group  Optional. The group the key is in. Default 'default'.
 	 * @return false|int False on failure, the item's new value on success.
 	 */
 	public function decr( $key, $offset = 1, $group = 'default' ) {
@@ -438,17 +478,17 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Remove the contents of the cache key in the group
+	 * Removes the contents of the cache key in the group.
 	 *
 	 * If the cache key does not exist in the group, then nothing will happen.
 	 *
 	 * @since 2.0.0
+	 * @access public
 	 *
-	 * @param int|string $key What the contents in the cache are called
-	 * @param string $group Where the cache contents are grouped
-	 * @param bool $deprecated Deprecated.
-	 *
-	 * @return bool False if the contents weren't deleted and true on success
+	 * @param int|string $key        What the contents in the cache are called.
+	 * @param string     $group      Optional. Where the cache contents are grouped. Default 'default'.
+	 * @param bool       $deprecated Optional. Unused. Default false.
+	 * @return bool False if the contents weren't deleted and true on success.
 	 */
 	public function delete( $key, $group = 'default', $deprecated = false ) {
 		if ( empty( $group ) )
@@ -465,20 +505,21 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Clears the object cache of all data
+	 * Clears the object cache of all data.
 	 *
 	 * @since 2.0.0
+	 * @access public
 	 *
-	 * @return bool Always returns true
+	 * @return true Always returns true.
 	 */
 	public function flush() {
-		$this->cache = array ();
+		$this->cache = array();
 
 		return true;
 	}
 
 	/**
-	 * Retrieves the cache contents, if it exists
+	 * Retrieves the cache contents, if it exists.
 	 *
 	 * The contents will be first attempted to be retrieved by searching by the
 	 * key in the cache group. If the cache is hit (success) then the contents
@@ -487,12 +528,15 @@ class WP_Object_Cache {
 	 * On failure, the number of cache misses will be incremented.
 	 *
 	 * @since 2.0.0
+	 * @access public
 	 *
-	 * @param int|string $key What the contents in the cache are called
-	 * @param string $group Where the cache contents are grouped
-	 * @param string $force Whether to force a refetch rather than relying on the local cache (default is false)
-	 * @return bool|mixed False on failure to retrieve contents or the cache
-	 *		contents on success
+	 * @param int|string $key    What the contents in the cache are called.
+	 * @param string     $group  Optional. Where the cache contents are grouped. Default 'default'.
+	 * @param string     $force  Optional. Unused. Whether to force a refetch rather than relying on the local
+	 *                           cache. Default false.
+	 * @param bool       $found  Optional. Whether the key was found in the cache. Disambiguates a return of
+	 *                           false, a storable value. Passed by reference. Default null.
+	 * @return false|mixed False on failure to retrieve contents or the cache contents on success.
 	 */
 	public function get( $key, $group = 'default', $force = false, &$found = null ) {
 		if ( empty( $group ) )
@@ -516,13 +560,14 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Increment numeric cache item's value
+	 * Increments numeric cache item's value.
 	 *
 	 * @since 3.3.0
+	 * @access public
 	 *
-	 * @param int|string $key The cache key to increment
-	 * @param int $offset The amount by which to increment the item's value. Default is 1.
-	 * @param string $group The group the key is in.
+	 * @param int|string $key    The cache key to increment
+	 * @param int        $offset Optional. The amount by which to increment the item's value. Default 1.
+	 * @param string     $group  Optional. The group the key is in. Default 'default'.
 	 * @return false|int False on failure, the item's new value on success.
 	 */
 	public function incr( $key, $offset = 1, $group = 'default' ) {
@@ -549,16 +594,18 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Replace the contents in the cache, if contents already exist
+	 * Replaces the contents in the cache, if contents already exist.
 	 *
 	 * @since 2.0.0
+	 * @access public
+	 *
 	 * @see WP_Object_Cache::set()
 	 *
-	 * @param int|string $key What to call the contents in the cache
-	 * @param mixed $data The contents to store in the cache
-	 * @param string $group Where to group the cache contents
-	 * @param int $expire When to expire the cache contents
-	 * @return bool False if not exists, true if contents were replaced
+	 * @param int|string $key    What to call the contents in the cache.
+	 * @param mixed      $data   The contents to store in the cache.
+	 * @param string     $group  Optional. Where to group the cache contents. Default 'default'.
+	 * @param int        $expire Optional. When to expire the cache contents. Default 0 (no expiration).
+	 * @return bool False if not exists, true if contents were replaced.
 	 */
 	public function replace( $key, $data, $group = 'default', $expire = 0 ) {
 		if ( empty( $group ) )
@@ -575,13 +622,16 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Reset keys
+	 * Resets cache keys.
 	 *
 	 * @since 3.0.0
-	 * @deprecated 3.5.0
+	 * @access public
+	 *
+	 * @deprecated 3.5.0 Use switch_to_blog()
+	 * @see switch_to_blog()
 	 */
 	public function reset() {
-		_deprecated_function( __FUNCTION__, '3.5', 'switch_to_blog()' );
+		_deprecated_function( __FUNCTION__, '3.5.0', 'switch_to_blog()' );
 
 		// Clear out non-global caches since the blog ID has changed.
 		foreach ( array_keys( $this->cache ) as $group ) {
@@ -591,7 +641,7 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Sets the data contents into the cache
+	 * Sets the data contents into the cache.
 	 *
 	 * The cache contents is grouped by the $group parameter followed by the
 	 * $key. This allows for duplicate ids in unique groups. Therefore, naming of
@@ -603,12 +653,13 @@ class WP_Object_Cache {
 	 * more for cache plugins which use files.
 	 *
 	 * @since 2.0.0
+	 * @access public
 	 *
-	 * @param int|string $key What to call the contents in the cache
-	 * @param mixed $data The contents to store in the cache
-	 * @param string $group Where to group the cache contents
-	 * @param int $expire Not Used
-	 * @return bool Always returns true
+	 * @param int|string $key    What to call the contents in the cache.
+	 * @param mixed      $data   The contents to store in the cache.
+	 * @param string     $group  Optional. Where to group the cache contents. Default 'default'.
+	 * @param int        $expire Not Used.
+	 * @return true Always returns true.
 	 */
 	public function set( $key, $data, $group = 'default', $expire = 0 ) {
 		if ( empty( $group ) )
@@ -631,6 +682,7 @@ class WP_Object_Cache {
 	 * key and the data.
 	 *
 	 * @since 2.0.0
+	 * @access public
 	 */
 	public function stats() {
 		echo "<p>";
@@ -645,13 +697,14 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Switch the interal blog id.
+	 * Switches the internal blog ID.
 	 *
-	 * This changes the blog id used to create keys in blog specific groups.
+	 * This changes the blog ID used to create keys in blog specific groups.
 	 *
 	 * @since 3.5.0
+	 * @access public
 	 *
-	 * @param int $blog_id Blog ID
+	 * @param int $blog_id Blog ID.
 	 */
 	public function switch_to_blog( $blog_id ) {
 		$blog_id = (int) $blog_id;
@@ -659,30 +712,27 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Utility function to determine whether a key exists in the cache.
+	 * Serves as a utility function to determine whether a key exists in the cache.
 	 *
 	 * @since 3.4.0
-	 *
 	 * @access protected
-	 * @param string $key
-	 * @param string $group
-	 * @return bool
+	 *
+	 * @param int|string $key   Cache key to check for existence.
+	 * @param string     $group Cache group for the key existence check.
+	 * @return bool Whether the key exists in the cache for the given group.
 	 */
 	protected function _exists( $key, $group ) {
 		return isset( $this->cache[ $group ] ) && ( isset( $this->cache[ $group ][ $key ] ) || array_key_exists( $key, $this->cache[ $group ] ) );
 	}
 
 	/**
-	 * Sets up object properties; PHP 5 style constructor
+	 * Sets up object properties; PHP 5 style constructor.
 	 *
 	 * @since 2.0.8
-	 * @return null|WP_Object_Cache If cache is disabled, returns null.
 	 */
 	public function __construct() {
-		global $blog_id;
-
 		$this->multisite = is_multisite();
-		$this->blog_prefix =  $this->multisite ? $blog_id . ':' : '';
+		$this->blog_prefix =  $this->multisite ? get_current_blog_id() . ':' : '';
 
 
 		/**
@@ -693,13 +743,13 @@ class WP_Object_Cache {
 	}
 
 	/**
-	 * Will save the object cache before object is completely destroyed.
+	 * Saves the object cache before object is completely destroyed.
 	 *
 	 * Called upon object destruction, which should be when PHP ends.
 	 *
-	 * @since  2.0.8
+	 * @since 2.0.8
 	 *
-	 * @return bool True value. Won't be used by PHP
+	 * @return true Always returns true.
 	 */
 	public function __destruct() {
 		return true;
